@@ -1,9 +1,11 @@
 import re
+from datetime import datetime
 
 import ujson as json
 import keypath
 
 from . import database
+from .persistent import Persistent
 
 
 def _extract(key_path):
@@ -241,6 +243,9 @@ class Query:
         for key_path, operator, operand, bind_type, \
             value_transformer in self._where:
 
+            if isinstance(operand, datetime):
+                key_path += '.iso'
+
             key_path = _extract(key_path)
 
             if value_transformer:
@@ -252,6 +257,10 @@ class Query:
 
                 if type(operand) in [tuple, list]:
                     values.extend(operand)
+                elif isinstance(operand, Persistent):
+                    values.append(operand.id)
+                elif isinstance(operand, datetime):
+                    values.append(operand.isoformat())
                 else:
                     values.append(operand)
             else:
